import { Subject } from 'rxjs';
import { OptionViewBase } from '@/studio-core';
import EAMAssetService from '@/service/eamasset/eamasset-service';
import EAMAssetAuthService from '@/authservice/eamasset/eamasset-auth-service';
import OptionViewEngine from '@engine/view/option-view-engine';
import EAMAssetUIService from '@/uiservice/eamasset/eamasset-ui-service';

/**
 * 资产快速新建视图视图基类
 *
 * @export
 * @class EAMAssetQuickCreateViewBase
 * @extends {OptionViewBase}
 */
export class EAMAssetQuickCreateViewBase extends OptionViewBase {
    /**
     * 视图对应应用实体名称
     *
     * @protected
     * @type {string}
     * @memberof EAMAssetQuickCreateViewBase
     */
    protected appDeName: string = 'eamasset';

    /**
     * 应用实体主键
     *
     * @protected
     * @type {string}
     * @memberof EAMAssetQuickCreateViewBase
     */
    protected appDeKey: string = 'assetid';

    /**
     * 应用实体主信息
     *
     * @protected
     * @type {string}
     * @memberof EAMAssetQuickCreateViewBase
     */
    protected appDeMajor: string = 'assetname';

    /**
     * 实体服务对象
     *
     * @type {EAMAssetService}
     * @memberof EAMAssetQuickCreateViewBase
     */
    protected appEntityService: EAMAssetService = new EAMAssetService;

    /**
     * 实体权限服务对象
     *
     * @type EAMAssetUIService
     * @memberof EAMAssetQuickCreateViewBase
     */
    public appUIService: EAMAssetUIService = new EAMAssetUIService(this.$store);


    /**
     * 计数器服务对象集合
     *
     * @protected
     * @type {Array<*>}
     * @memberof EAMAssetQuickCreateViewBase
     */    
    protected counterServiceArray: Array<any> = [];

    /**
     * 视图模型数据
     *
     * @protected
     * @type {*}
     * @memberof EAMAssetQuickCreateViewBase
     */
    protected model: any = {
        srfCaption: 'entities.eamasset.views.quickcreateview.caption',
        srfTitle: 'entities.eamasset.views.quickcreateview.title',
        srfSubTitle: 'entities.eamasset.views.quickcreateview.subtitle',
        dataInfo: ''
    }

    /**
     * 容器模型
     *
     * @protected
     * @type {*}
     * @memberof EAMAssetQuickCreateViewBase
     */
    protected containerModel: any = {
        view_form: { name: 'form', type: 'FORM' },
        view_okbtn: { name: 'okbtn', type: 'button', text: '确定', disabled: true },
        view_cancelbtn: { name: 'cancelbtn', type: 'button', text: '取消', disabled: false },
        view_leftbtn: { name: 'leftbtn', type: 'button', text: '左移', disabled: true },
        view_rightbtn: { name: 'rightbtn', type: 'button', text: '右移', disabled: true },
        view_allleftbtn: { name: 'allleftbtn', type: 'button', text: '全部左移', disabled: true },
        view_allrightbtn: { name: 'allrightbtn', type: 'button', text: '全部右移', disabled: true },
    };


	/**
     * 视图唯一标识
     *
     * @protected
     * @type {string}
     * @memberof ViewBase
     */
	protected viewtag: string = 'bcdc34d8df9323426a402ba7b111fef2';


    /**
     * 视图引擎
     *
     * @public
     * @type {Engine}
     * @memberof EAMAssetQuickCreateViewBase
     */
    public engine: OptionViewEngine = new OptionViewEngine();

    /**
     * 引擎初始化
     *
     * @public
     * @memberof EAMAssetQuickCreateViewBase
     */
    public engineInit(): void {
        this.engine.init({
            view: this,
            form: this.$refs.form,
            p2k: '0',
            keyPSDEField: 'eamasset',
            majorPSDEField: 'assetname',
            isLoadDefault: true,
        });
    }

    /**
     * form 部件 save 事件
     *
     * @param {*} [args={}]
     * @param {*} $event
     * @memberof EAMAssetQuickCreateViewBase
     */
    public form_save($event: any, $event2?: any): void {
        this.engine.onCtrlEvent('form', 'save', $event);
    }

    /**
     * form 部件 remove 事件
     *
     * @param {*} [args={}]
     * @param {*} $event
     * @memberof EAMAssetQuickCreateViewBase
     */
    public form_remove($event: any, $event2?: any): void {
        this.engine.onCtrlEvent('form', 'remove', $event);
    }

    /**
     * form 部件 load 事件
     *
     * @param {*} [args={}]
     * @param {*} $event
     * @memberof EAMAssetQuickCreateViewBase
     */
    public form_load($event: any, $event2?: any): void {
        this.engine.onCtrlEvent('form', 'load', $event);
    }


}